
#include "dact.h"
#include "config.h"

#if defined(USE_MODULES) && defined(COMP_MZLIB_IS_MOD) && !defined(AS_MODULE) && defined(USE_ZLIB)
#define comp_mzlib_algo DACT_FAILED_ALGO
#else
int comp_mzlib_algo(int mode, unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
int comp_mzlib_compress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
int comp_mzlib_decompress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
#endif
